@@ -395,6 +395,11 @@ class Onglets(wx.Notebook):
             self.general_elements["arguments"].SetValue(playonlinux.getArgs(self.s_title))
 
             self.display_elements["folder_button"].SetLabel(_("Open program's directory"))
+            if not playonlinux.GetSettings("OPEN_IN", self.s_prefix):
+                self.display_elements["open_in"].SetValue("xdg-open")
+            else:
+                self.display_elements["open_in"].SetValue(playonlinux.GetSettings("OPEN_IN", self.s_prefix))
+
             if(os.path.exists(Variables.playonlinux_rep+"configurations/configurators/"+self.s_title)):
                 self.configurator_title.Show()
                 self.configurator_button.Show()
@@ -471,16 +476,16 @@ class Onglets(wx.Notebook):
         param = event.GetId()
         if(param == 402):
             if(self.s_isPrefix == False):
-                playonlinux.open_folder(self.s_title)
+                playonlinux.open_folder(self.s_title, self.display_elements["open_in"].GetValue().encode("utf-8","replace"))
             else:
                 playonlinux.open_folder_prefix(self.s_prefix)
-        if(param == 403):
+        if(param == 404):
             if(self.s_isPrefix == False):
                 subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/POL_Command", self.s_title.encode('utf-8','replace'), "POL_OpenShell", self.s_title.encode('utf-8','replace')])
             else:
                 subprocess.Popen(["bash", Variables.playonlinux_env+"/bash/POL_Command", "--prefix", self.s_prefix.encode('utf-8','replace'), "POL_OpenShell"])
 
-        if(param == 404):
+        if(param == 405):
             self.FileDialog = wx.FileDialog(self)
             self.FileDialog.SetDirectory("~")
             self.supported_files = "All|*.exe;*.EXE;*.msi;*.MSI\
@@ -531,6 +536,15 @@ class Onglets(wx.Notebook):
 
         wx.EVT_BUTTON(self, 400+num,  self.misc_button)
 
+    def AddMiscChamp(self, title, shortname, value, num):
+        self.display_elements[shortname+"_text"] = wx.StaticText(self.panelMisc, -1, title,pos=(15,24+num*40))
+        self.display_elements[shortname] = wx.TextCtrl(self.panelMisc, 400+num, value, pos=(245,19+num*40), size=(270,25))
+        wx.EVT_TEXT(self, 400+num, self.set_open_in)
+
+    def set_open_in(self, event):
+        new_open_in = self.display_elements["open_in"].GetValue()
+        playonlinux.SetSettings('OPEN_IN', new_open_in, self.s_prefix)
+
     def AddMiscLongText(self, title, shortname, num):
         self.display_elements[shortname+"_text"] = wx.StaticText(self.panelMisc, -1, title,pos=(15,19+num*40))
         self.display_elements[shortname+"_panel"] = wx.Panel(self.panelMisc, -1, size=wx.Size(450,70),pos=(20,44+num*40))
@@ -541,7 +555,7 @@ class Onglets(wx.Notebook):
             content = ""
 
         self.display_elements[shortname] = wx.TextCtrl(self.display_elements[shortname+"_panel"], 400+num, content, size=wx.Size(448,68), pos=(2,2), style=Variables.widget_borders|wx.TE_MULTILINE)
-        wx.EVT_TEXT(self, 405,  self.edit_shortcut)
+        wx.EVT_TEXT(self, 400+num,  self.edit_shortcut)
 
     def edit_shortcut(self, event):
         content = self.display_elements["pre_run"].GetValue().encode("utf-8","replace")
@@ -579,9 +593,10 @@ class Onglets(wx.Notebook):
 
         self.AddMiscElement(_("Mouse warp override"),"MouseWarpOverride",["Enabled","Disabled","Force"],["enable","disable","force"],1)
         self.AddMiscButton("","folder",2)
-        self.AddMiscButton(_("Open a shell"),"shell",3)
-        self.AddMiscButton(_("Run a .exe file in this virtual drive"),"exerun",4)
-        self.AddMiscLongText(_("Command to exec before running the program"),"pre_run",5)
+        self.AddMiscChamp(_("Open directory using command"),"open_in","",3)
+        self.AddMiscButton(_("Open a shell"),"shell",4)
+        self.AddMiscButton(_("Run a .exe file in this virtual drive"),"exerun",5)
+        self.AddMiscLongText(_("Command to exec before running the program"),"pre_run",6)
 
         self.AddPage(self.panelMisc, nom)
 
